flagship library

Classes

CampaignActionMessage
Message for campaign actions (hide/unhide)
Flagship
HitEventMessage
Message containing hit event information
ModificationMessage
Represents a modification object to be sent to Flagship (New format)
QAMessageService
Service responsible for sending messages from QA Assistant to Flagship using streams
VariationInfo
Represents a variation object

Properties

getIt → GetIt
Get the GetIt instance
final

Functions

cleanupQAServiceLocator() → void
Clean up the service locator
getQAMessageService() QAMessageService
Get the QAMessageService instance
setupQAServiceLocator() → void
Initialize the QA Assistant service locator This should be called once at app startup