onFlagUpdate property

void Function(List<String> changedFlagKeys)? onFlagUpdate
getter/setter pair

Optional callback that is triggered when flags are updated by QA Assistant This allows clients to refresh their UI in response to QA changes Usage: visitor.onFlagUpdate = (changedKeys) => setState(() { /* refresh */ });

Implementation

void Function(List<String> changedFlagKeys)? onFlagUpdate;