ModificationMessage class
Represents a modification object to be sent to Flagship (New format)
Constructors
- ModificationMessage({required String campaignId, required String campaignName, required String campaignType, String? campaignSlug, required String variationGroupId, required String variationGroupName, required VariationInfo variation})
-
ModificationMessage.fromJson(Map<
String, dynamic> json) -
Create from JSON (expects the new format with campaignId as key)
factory
- ModificationMessage.fromJsonString(String jsonString)
-
Create from JSON string
factory
Properties
- campaignId → String
-
final
- campaignName → String
-
final
- campaignSlug → String?
-
final
- campaignType → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
- variation → VariationInfo
-
final
- variationGroupId → String
-
final
- variationGroupName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON format with campaignId as key
-
toJsonString(
) → String - Convert to JSON string
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited