QAMessageService class
Service responsible for sending messages from QA Assistant to Flagship using streams
Constructors
Properties
-
campaignActionStream
→ Stream<
CampaignActionMessage> -
Stream of campaign actions (hide/unhide)
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hitEventStream
→ Stream<
HitEventMessage> -
Stream of hit events
no setter
-
liveVariationsIdsStream
→ Stream<
Map< String, dynamic> > -
Stream of fetched flag IDs updates
no setter
-
modificationMessageStream
→ Stream<
ModificationMessage> -
Stream of modification messages
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
startCommandStream
→ Stream<
void> -
Stream of start QA Assistant commands
no setter
-
stopCommandStream
→ Stream<
void> -
Stream of stop QA Assistant commands
no setter
-
userContextRequestStream
→ Stream<
void> -
Stream of user context request
no setter
-
userContextUpdateStream
→ Stream<
Map< String, dynamic> > -
Stream of the userc ontext updates
no setter
Methods
-
broadcastFetchedFlagIds(
List< Map< fetchedFlagIds) → voidString, String> > - Broadcast fetched flag IDs from Flagship SDK to QA Assistant
-
broadcastHitEvent(
dynamic hit, Map< String, dynamic> payload) → void - Broadcast hit event from Flagship SDK to QA Assistant
-
broadcastStartQAAssistant(
) → void - Broadcast start QA Assistant command from Flagship SDK
-
broadcastStopQAAssistant(
) → void - Broadcast stop QA Assistant command from Flagship SDK
-
broadcastUserContextRequest(
) → void - Request user context from Flagship SDK
-
broadcastUserContextUpdate(
Map< String, dynamic> userContext) → void -
dispose(
) → void - Dispose all stream controllers
-
hideCampaign(
String campaignId) → void - Send hide campaign message
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendModification(
{required String campaignId, required String campaignName, required String campaignType, String? campaignSlug, required String variationGroupId, required String variationGroupName, required String variationId, required String variationName, required bool isReference, required Map< String, dynamic> modifications}) → void - Send modification message to Flagship (New format)
-
sendModificationMessage(
ModificationMessage message) → void - Send modification message using ModificationMessage object
-
toString(
) → String -
A string representation of this object.
inherited
-
unhideCampaign(
String campaignId) → void - Send unhide campaign message
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited