QassistantStrategy class

QA Assistant Strategy that connects to QA Assistant package

Inheritance

Constructors

QassistantStrategy(Visitor visitor)

Properties

hashCode int
The hash code for this object.
no setterinherited
hiddenCampaigns Set<String>
Set of hidden campaign IDs - these should return null (default value)
final
qaaModifications Map<String, Modification>
Map des modifications QA qui override celles du visitor
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visitor Visitor
finalinherited

Methods

activateFlag(Modification pModification, {bool isDuplicated = false}) Future<void>
override
authenticateVisitor(String pVisitorId) → dynamic
inherited
cacheVisitor(String pVisitorId, String jsonString) → void
inherited
cleanup() → void
collectEmotionsAIEvents(String screenName) → dynamic
inherited
fetchFlags() Future<FetchResponse?>
override
getFlagModification(String key) Modification?
override
getFlagStatus(String key) FlagStatus
inherited
getModification<T>(String key, T defaultValue, {bool activate = false}) → T
inherited
getModificationInfo(String key) Map<String, dynamic>?
inherited
hideCampaign(String campaignId) → void
inherited
lookupHits() → void
inherited
lookupVisitor(String visitorId) Future<bool>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAppScreenChange(String screenName) → dynamic
inherited
onExposure(Modification pModification) → void
inherited
sendHit(BaseHit hit) Future<void>
override
setConsent(bool isConsent) → void
inherited
toString() String
A string representation of this object.
inherited
unAuthenticateVisitor() → dynamic
inherited
unhideCampaign(String campaignId) → void
inherited
updateContext<T>(String key, T value) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited